@@ -1,7 +1,7 @@
 """
     jupylet/__init__.py
     
-    Copyright (c) 2020, Nir Aides - nir@winpdb.org
+    Copyright (c) 2022, Nir Aides - nir.8bit@gmail.com
 
     Redistribution and use in source and binary forms, with or without
     modification, are permitted provided that the following conditions are met:
@@ -33,7 +33,7 @@ import re
 from .env import is_remote, has_display, is_numpy_openblas
 
 
-VERSION = '0.8.8'
+VERSION = '0.8.9'
 
 
 if platform.system() == 'Linux' and not has_display():
@@ -48,7 +48,7 @@ if platform.system() == 'Darwin':
    if 'numpy' in sys.modules and is_numpy_openblas():
       sys.stderr.write(
          'WARNING: numpy was imported before jupylet. ' + 
-         'On Mac OS X you should import jupylet first to let it work around ' +
+         'On macOS you should import jupylet first to let it work around ' +
          'a bug in the algebra libraries used by numpy that may cause the ' +
          'program to exit.' + '\n'
       )
