@@ -1,7 +1,7 @@
 """
     jupylet/model.py
     
-    Copyright (c) 2020, Nir Aides - nir@winpdb.org
+    Copyright (c) 2022, Nir Aides - nir.8bit@gmail.com
 
     Redistribution and use in source and binary forms, with or without
     modification, are permitted provided that the following conditions are met:
@@ -421,7 +421,7 @@ class Material(Object):
                     
             shader._members[material + 'emissive_texture'].value = self._emissive
             if self._emissive < 0:
-                shader._members[material + 'emissive'].value = tuple(self.emissive)
+                shader._members[material + 'emissive'].value = tuple(self.emissive or [0, 0, 0])
 
             shader._members[material + 'roughness_texture'].value = self._roughness
             if self._roughness < 0:
